import boto3

from functools import partial


def build(args):
    if args.region:
        boto3.setup_default_session(region_name=args.region)

    client = partial(boto3.client, 'ec2')
    key_id = args.aws_access_key_id
    access_key = args.aws_secret_access_key

    if key_id and access_key:
        return client(
            aws_access_key_id=key_id,
            aws_secret_access_key=access_key)
    else:
        return client()



class Instance():
    def __init__(self, response):
        self.id = response['InstanceId']
        self.volume_id = response['BlockDeviceMappings'][0]['Ebs']['VolumeId']
        self.launch_time = response['LaunchTime']
        self.ip_address = response['PublicIpAddress']


class InstanceList():
    def __init__(self, response):
        self.instances = []
        for reservation in response['Reservations']:
            for insta in reservation['Instances']:
                self.instances.append(Instance(insta))

    def latest(self):
        return sorted(self.instances, key=lambda i: i.launch_time)[0]


def find_latest(client, config):
    instance_response = client.describe_instances(
        Filters=[{'Name': 'tag:project', 'Values': [config.instance_tag]}])
    return InstanceList(instance_response).latest()


def destroy(client, instance_id):
    return client.terminate_instances(InstanceIds=[instance_id])


def tag(client, instance_id, config):
    return client.create_tags(
        Resources=[instance_id],
        Tags=[{'Key': 'project', 'Value': config.instance_tag, }]
    )


def get_by_instance_id(client, instance_id):
    response = client.describe_instances(InstanceIds=[instance_id])
    return Instance(response['Reservations'][0]['Instances'][0])



#!/usr/bin/env python
import codecs
import os.path
import re
import sys
from setuptools import find_packages, setup
from spotr import version

setup(
    name = 'spotr',
    version = version.VERSION,
    description = '',
    long_description=open('README.rst').read(),
    url = 'https://github.com/samuelreh/spotr',
    author = 'Samuel Reh',
    author_email = 'samuelreh@gmail.com',
    license = 'UNLICENSE',
    classifiers = [
        'Intended Audience :: Developers',
        'Topic :: Utilities',
        'License :: Public Domain',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
    keywords = 'cli',
    packages = find_packages(exclude=['docs', 'tests*']),
    install_requires = ['docopt', 'boto3'],
    test_require=['coverage', 'pytest', 'pytest-cov', 'mock'],
    entry_points = {
        'console_scripts': [
            'spotr=spotr.spotr:main',
        ],
    },
)
